Merge pull request #38381 from bambadiouf1/fix-fhir-search-sig

Fix FHIR search method signature mismatch after google.golang.org/api
diff --git a/sdks/go/pkg/beam/io/fhirio/common.go b/sdks/go/pkg/beam/io/fhirio/common.go
index 504e652..9f7e39b 100644
--- a/sdks/go/pkg/beam/io/fhirio/common.go
+++ b/sdks/go/pkg/beam/io/fhirio/common.go
@@ -127,12 +127,12 @@
 		queryParams = append(queryParams, googleapi.QueryParameter(pageTokenParameterKey, pageToken))
 	}
 
 	// Pass nil as the body because search parameters are passed via queryParams,
 	// and the new API expects an io.Reader instead of a specific struct.
 	if resourceType == "" {
-		return c.fhirService().Search(storePath, nil).Do(queryParams...)
+		return c.fhirService().Search(storePath, strings.NewReader("")).Do(queryParams...)
 	}
-	return c.fhirService().SearchType(storePath, resourceType, nil).Do(queryParams...)
+	return c.fhirService().SearchType(storePath, resourceType, strings.NewReader("")).Do(queryParams...)
 }
 
 func (c *fhirStoreClientImpl) deidentify(srcStorePath, dstStorePath string, deidConfig *healthcare.DeidentifyConfig) (operationResults, error) {
@@ -127,12 +127,12 @@
 	}
 
-	// Pass nil as the body because search parameters are passed via queryParams,
+	// Pass an empty reader as the body because search parameters are passed via queryParams,
 	// and the new API expects an io.Reader instead of a specific struct.
 	if resourceType == "" {